@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-client
 version: 0.4.27
-id: http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
-key: httpc_5i8mkFmC9bvG1ll2PGXFGo
+id: http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
+key: httpc_BK8pBIZK5eBJ6SslCRgQ3D
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/http-client
@@ -28,7 +28,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-0.4.27
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-0.4.27
-hs-libraries: HShttp-client-0.4.27-5i8mkFmC9bvG1ll2PGXFGo
+hs-libraries: HShttp-client-0.4.27-BK8pBIZK5eBJ6SslCRgQ3D
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -48,7 +48,7 @@ depends:
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
+    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
